@@ -20,47 +20,45 @@
 
 #include "navigator.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
 #include <QDir>
 #include <QFile>
 #include <QPixmap>
 
 #include <QLabel>
-#include <Qt3Support/Q3Header>
 #include <QtXml/QtXml>
 #include <QTextStream>
 #include <QRegExp>
 #include <QLayout>
 #include <QPushButton>
-
-//Added by qt3to4:
 #include <QFrame>
 #include <QHBoxLayout>
 #include <QBoxLayout>
 #include <QVBoxLayout>
+#include <QTreeWidgetItemIterator>
+
+#include <KAction>
+#include <KApplication>
+#include <KConfig>
+#include <KStandardDirs>
+#include <KGlobal>
+#include <KLocale>
+#include <KDebug>
 
-#include <kaction.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kstandarddirs.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <k3listview.h>
 #include <KLineEdit>
-#include <kmessagebox.h>
-#include <kiconloader.h>
-#include <kcharsets.h>
-#include <kdialog.h>
-#include <kdesktopfile.h>
-#include <kprotocolinfo.h>
-#include <kservicegroup.h>
-#include <kservicetypetrader.h>
-#include <kcmoduleinfo.h>
-#include <kcmodule.h>
+#include <KMessageBox>
+#include <KIconLoader>
+#include <KCharsets>
+#include <KDialog>
+#include <KDesktopFile>
+#include <KProtocolInfo>
+#include <KServiceGroup>
+#include <KServiceTypeTrader>
+#include <KCModuleInfo>
+#include <KCModule>
+
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "navigatoritem.h"
 #include "navigatorappitem.h"
@@ -125,13 +123,15 @@ Navigator::Navigator( View *view, QWidget *parent, const char *name )
     setupSearchTab();
 
     insertPlugins();
-
+    hideSearch();
+/*
     if ( !mSearchEngine->initSearchHandlers() ) {
       hideSearch();
     } else {
       mSearchWidget->updateScopeList();
       mSearchWidget->readConfig( KGlobal::config().data() );
     }
+    */
     connect( mTabWidget, SIGNAL( currentChanged( QWidget * ) ),
              SLOT( slotTabChanged( QWidget * ) ) );
 }
@@ -158,23 +158,21 @@ bool Navigator::showMissingDocs() const
 
 void Navigator::setupContentsTab()
 {
-    mContentsTree = new K3ListView( mTabWidget );
+    mContentsTree = new QTreeWidget( mTabWidget );
     mContentsTree->setFrameStyle( QFrame::NoFrame );
-    mContentsTree->addColumn(QString());
     mContentsTree->setAllColumnsShowFocus(true);
-    mContentsTree->header()->hide();
     mContentsTree->setRootIsDecorated(false);
-    mContentsTree->setSorting(-1, false);
+    mContentsTree->headerItem()->setHidden(true);
 
-    connect(mContentsTree, SIGNAL(clicked(Q3ListViewItem*)),
-            SLOT(slotItemSelected(Q3ListViewItem*)));
-    connect(mContentsTree, SIGNAL(returnPressed(Q3ListViewItem*)),
-           SLOT(slotItemSelected(Q3ListViewItem*)));
+    connect(mContentsTree, SIGNAL(itemActivated(QTreeWidgetItem*,int)),
+            SLOT(slotItemSelected(QTreeWidgetItem*)));
+    
     mTabWidget->addTab(mContentsTree, i18n("&Contents"));
 }
 
 void Navigator::setupSearchTab()
 {
+  
     mSearchWidget = new SearchWidget( mSearchEngine, mTabWidget );
     connect( mSearchWidget, SIGNAL( searchResult( const QString & ) ),
              SLOT( slotShowSearchResult( const QString & ) ) );
@@ -184,6 +182,7 @@ void Navigator::setupSearchTab()
       SLOT( showIndexDialog() ) );
 
     mTabWidget->addTab( mSearchWidget, i18n("Search Options"));
+    
 }
 
 void Navigator::setupGlossaryTab()
@@ -198,16 +197,6 @@ void Navigator::insertPlugins()
 {
   PluginTraverser t( this, mContentsTree );
   DocMetaInfo::self()->traverseEntries( &t );
-
-#if 0
-  kDebug( 1400 ) << "<docmetainfo>";
-  DocEntry::List entries = DocMetaInfo::self()->docEntries();
-  DocEntry::List::ConstIterator it;
-  for( it = entries.begin(); it != entries.end(); ++it ) {
-    (*it)->dump();
-  }
-  kDebug( 1400 ) << "</docmetainfo>";
-#endif
 }
 
 void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem )
@@ -219,8 +208,8 @@ void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem
     return;
 
   KServiceGroup::List entries = grp->entries();
-  KServiceGroup::List::ConstIterator it = entries.begin();
-  KServiceGroup::List::ConstIterator end = entries.end();
+  KServiceGroup::List::ConstIterator it = entries.constBegin();
+  KServiceGroup::List::ConstIterator end = entries.constEnd();
   for ( ; it != end; ++it ) {
     QString desktopFile = ( *it )->entryPath();
     if ( QDir::isRelativePath( desktopFile ) )
@@ -231,7 +220,7 @@ void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem
 
 void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, const QString &type )
 {
-  kDebug(1400) << "Requested IOSlave documents for ID " << name;
+  kDebug(1400) << "Requested KCM documents for ID" << name;
 
   KService::List list;
 
@@ -241,11 +230,10 @@ void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, cons
     list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kinfocenter'" );
   }
 
-  NavigatorItem *prevItem = 0;
-  for ( KService::List::const_iterator it = list.begin(); it != list.end(); ++it )
+  for ( KService::List::const_iterator it = list.constBegin(); it != list.constEnd(); ++it )
   {
     KService::Ptr s = (*it);
-    KCModuleInfo m = KCModuleInfo::KCModuleInfo(s);
+    KCModuleInfo m = KCModuleInfo(s);
     QString desktopFile = KStandardDirs::locate( "services", m.fileName() );
     createItemFromDesktopFile( topItem, desktopFile );
     }
@@ -253,13 +241,13 @@ void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, cons
 
 void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
 {
-  kDebug(1400) << "Requested IOSlave documents for ID " << name;
+  kDebug(1400) << "Requested IOSlave documents for ID" << name;
 
   QStringList list = KProtocolInfo::protocols();
   list.sort();
 
   NavigatorItem *prevItem = 0;
-  for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it )
+  for ( QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it )
   {
     QString docPath = KProtocolInfo::docPath(*it);
     if ( !docPath.isNull() )
@@ -276,18 +264,6 @@ void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
   }
 }
 
-void Navigator::insertAppletDocs( NavigatorItem *topItem )
-{
-  QDir appletDir( KStandardDirs::locate( "data", QLatin1String( "kicker/applets/" ) ) );
-  appletDir.setNameFilters( QStringList( "*.desktop" ) );
-
-  QStringList files = appletDir.entryList( QDir::Files | QDir::Readable );
-  QStringList::ConstIterator it = files.begin();
-  QStringList::ConstIterator end = files.end();
-  for ( ; it != end; ++it )
-    createItemFromDesktopFile( topItem, appletDir.absolutePath() + '/' + *it );
-}
-
 void Navigator::createItemFromDesktopFile( NavigatorItem *topItem,
                                            const QString &file )
 {
@@ -338,7 +314,7 @@ void Navigator::selectItem( const KUrl &url )
 
   // If the navigator already has the given URL selected, do nothing.
   NavigatorItem *item;
-  item = static_cast<NavigatorItem *>( mContentsTree->selectedItem() );
+  item = static_cast<NavigatorItem *>( mContentsTree->currentItem() );
   if ( item && mSelected ) {
     KUrl currentURL ( item->entry()->url() );
     if ( (currentURL == url) || (currentURL == alternativeURL) ) {
@@ -349,29 +325,30 @@ void Navigator::selectItem( const KUrl &url )
 
   // First, populate the NavigatorAppItems if we don't want the home page
   if ( url != homeURL() ) {
-    for ( Q3ListViewItem *item = mContentsTree->firstChild(); item;
-          item = item->nextSibling() ) {
-      NavigatorAppItem *appItem = dynamic_cast<NavigatorAppItem *>( item );
-      if ( appItem ) appItem->populate( true /* recursive */ );
+    QTreeWidgetItemIterator it1( mContentsTree );
+    while( (*it1) ) 
+    {
+      NavigatorAppItem *appItem = dynamic_cast<NavigatorAppItem *>( (*it1) );
+      if ( appItem ) appItem->populate( true );
+      ++it1;
     }
   }
-
-  Q3ListViewItemIterator it( mContentsTree );
-  while ( it.current() ) {
-    NavigatorItem *item = static_cast<NavigatorItem *>( it.current() );
+  
+  QTreeWidgetItemIterator it( mContentsTree );
+  while ( (*it) ) {
+    NavigatorItem *item = static_cast<NavigatorItem *>( (*it) );
     KUrl itemUrl( item->entry()->url() );
     if ( (itemUrl == url) || (itemUrl == alternativeURL) ) {
       mContentsTree->setCurrentItem( item );
       // If the current item was not selected and remained unchanged it
       // needs to be explicitly selected
-      mContentsTree->setSelected(item, true);
-      item->setOpen( true );
-      mContentsTree->ensureItemVisible( item );
+      mContentsTree->setCurrentItem(item);
+      item->setExpanded( true );
       break;
     }
     ++it;
   }
-  if ( !it.current() ) {
+  if ( !(*it) ) {
     clearSelection();
   } else {
     mSelected = true;
@@ -384,7 +361,7 @@ void Navigator::clearSelection()
   mSelected = false;
 }
 
-void Navigator::slotItemSelected( Q3ListViewItem *currentItem )
+void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
 {
   if ( !currentItem ) return;
 
@@ -392,42 +369,22 @@ void Navigator::slotItemSelected( Q3ListViewItem *currentItem )
 
   NavigatorItem *item = static_cast<NavigatorItem *>( currentItem );
 
-  kDebug(1400) << "Navigator::slotItemSelected(): " << item->entry()->name()
-                << endl;
+  kDebug(1400) << item->entry()->name() << endl;
 
-  if ( item->childCount() > 0 || item->isExpandable() )
-    item->setOpen( !item->isOpen() );
+  if ( item->childCount() > 0  )
+    item->setExpanded( !item->isExpanded() );
 
   KUrl url ( item->entry()->url() );
 
+  
+  
   if ( url.protocol() == "khelpcenter" ) {
       mView->closeUrl();
       History::self().updateCurrentEntry( mView );
       History::self().createEntry();
       showOverview( item, url );
   } else {
-    if ( url.protocol() == "help" ) {
-      kDebug( 1400 ) << "slotItemSelected(): Got help URL " << url.url()
-                      << endl;
-      if ( !item->toc() ) {
-        TOC *tocTree = item->createTOC();
-        kDebug( 1400 ) << "slotItemSelected(): Trying to build TOC for "
-                        << item->entry()->name() << endl;
-        tocTree->setApplication( url.directory() );
-        QString doc = View::langLookup( url.path() );
-        // Enforce the original .docbook version, in case langLookup returns a
-        // cached version
-        if ( !doc.isNull() ) {
-          int pos = doc.indexOf( ".html" );
-          if ( pos >= 0 ) {
-            doc.replace( pos, 5, ".docbook" );
-          }
-          kDebug( 1400 ) << "slotItemSelected(): doc = " << doc;
-
-          tocTree->build( doc );
-        }
-      }
-    }
+   
     emit itemSelected( url.url() );
   }
 
@@ -482,13 +439,13 @@ void Navigator::showOverview( NavigatorItem *item, const KUrl &url )
     title = i18n("Start Page");
     name = i18n("KDE Help Center");
 
-    childCount = mContentsTree->childCount();
+    childCount = mContentsTree->topLevelItemCount();
   }
 
   if ( childCount > 0 ) {
-    Q3ListViewItem *child;
-    if ( item ) child = item->firstChild();
-    else child = mContentsTree->firstChild();
+    QTreeWidgetItem *child;
+    if ( item ) child = item;
+    else child = mContentsTree->invisibleRootItem();
 
     mDirLevel = 0;
 
@@ -504,7 +461,7 @@ void Navigator::showOverview( NavigatorItem *item, const KUrl &url )
   mView->end();
 }
 
-QString Navigator::createChildrenList( Q3ListViewItem *child )
+QString Navigator::createChildrenList( QTreeWidgetItem *child )
 {
   ++mDirLevel;
 
@@ -512,8 +469,10 @@ QString Navigator::createChildrenList( Q3ListViewItem *child )
 
   t += QLatin1String("<ul>\n");
 
-  while ( child ) {
-    NavigatorItem *childItem = static_cast<NavigatorItem *>( child );
+  int cc = child->childCount();
+  for (int i=0;i<cc;i++) 
+  {
+    NavigatorItem *childItem = static_cast<NavigatorItem *>( child->child(i) );
 
     DocEntry *e = childItem->entry();
 
@@ -530,10 +489,9 @@ QString Navigator::createChildrenList( Q3ListViewItem *child )
     t += QLatin1String("</li>\n");
 
     if ( childItem->childCount() > 0 && mDirLevel < 2 ) {
-      t += createChildrenList( childItem->firstChild() );
+      t += createChildrenList( childItem );
     }
 
-    child = child->nextSibling();
   }
 
   t += QLatin1String("</ul>\n");
@@ -545,6 +503,7 @@ QString Navigator::createChildrenList( Q3ListViewItem *child )
 
 void Navigator::slotSearch()
 {
+  
   kDebug(1400) << "Navigator::slotSearch()";
 
   if ( !checkSearchIndex() ) return;
@@ -569,6 +528,7 @@ void Navigator::slotSearch()
     slotSearchFinished();
     KMessageBox::sorry( this, i18n("Unable to run search program.") );
   }
+  
 }
 
 void Navigator::slotShowSearchResult( const QString &url )
@@ -594,6 +554,7 @@ void Navigator::checkSearchButton()
   mTabWidget->setCurrentIndex( mTabWidget->indexOf( mSearchWidget ) );
 }
 
+
 void Navigator::hideSearch()
 {
   mSearchFrame->hide();
