@@ -30,7 +30,6 @@
 #include "config-fish.h"
 #include <QFile>
 #include <QDateTime>
-#include <QBitArray>
 #include <QRegExp>
 #include <QCoreApplication>
 
@@ -518,11 +517,14 @@ bool fishProtocol::connectionStart() {
             myDebug( << "select failed, rc: " << rc << ", error: " << strerror(errno) << endl);
             return true;
         }
-        while (FD_ISSET(childFd,&wfds) && outBufPos >= 0) 
-	{
-            if (outBuf) rc = ::write(childFd,outBuf+outBufPos,outBufLen-outBufPos);
-            else rc = 0;
-            if (rc >= 0) outBufPos += rc;
+        if (FD_ISSET(childFd, &wfds) && outBufPos >= 0) {
+            if (outBuf)
+                rc = ::write(childFd, outBuf + outBufPos, outBufLen - outBufPos);
+            else
+                rc = 0;
+
+            if (rc >= 0)
+                outBufPos += rc;
             else {
                 if (errno == EINTR)
                     continue;
@@ -535,14 +537,14 @@ bool fishProtocol::connectionStart() {
                 outBuf = NULL;
                 outBufLen = 0;
             }
-        }
-        if (FD_ISSET(childFd,&rfds)) 
-	{
-            rc = ::read(childFd,buf+offset,32768-offset);
+        } else if (FD_ISSET(childFd,&rfds)) {
+            rc = ::read(childFd, buf + offset, sizeof(buf) - offset);
             if (rc > 0) {
-                int noff = establishConnection(buf,rc+offset);
-                if (noff < 0) return false;
-                if (noff > 0) memmove(buf,buf+offset+rc-noff,noff);
+                int noff = establishConnection(buf, rc + offset);
+                if (noff < 0)
+                    return false;
+                if (noff > 0)
+                    memmove(buf, buf + offset + rc - noff, noff);
                 offset = noff;
             } else {
                 if (errno == EINTR)
@@ -689,7 +691,7 @@ int fishProtocol::establishConnection(const QByteArray &buffer) {
             myDebug( << "unmatched case in initial handling! should not happen!" << endl);
         }
 #ifdef Q_WS_WIN
-        if (buf.endsWith("(y/n)")) {
+        if (buf.endsWith(QLatin1String("(y/n)"))) {
             int rc = messageBox(QuestionYesNo,thisFn+buf);
             if (rc == KMessageBox::Yes) {
                 writeChild("y\n",2);
@@ -821,7 +823,7 @@ checks response string for result code, converting 000 and 001 appropriately
 */
 int fishProtocol::handleResponse(const QString &str){
     myDebug( << "handling: " << str << endl);
-    if (str.startsWith("### ")) {
+    if (str.startsWith(QLatin1String("### "))) {
         bool isOk = false;
         int result = str.mid(4,3).toInt(&isOk);
         if (!isOk) result = 500;
@@ -879,7 +881,7 @@ void fishProtocol::manageConnection(const QString &l) {
     if (!rc) {
         switch (fishCommand) {
         case FISH_VER:
-            if (line.startsWith("VER 0.0.3")) {
+            if (line.startsWith(QLatin1String("VER 0.0.3"))) {
                 line.append(" ");
                 hasAppend = line.contains(" append ");
             } else {
@@ -957,7 +959,7 @@ void fishProtocol::manageConnection(const QString &l) {
                     if (line[10] == 'T' || line[10] == 't') accessVal |= S_ISVTX;
                     udsEntry.insert(KIO::UDSEntry::UDS_ACCESS, accessVal);
 
-                    pos = line.indexOf('.',12);
+                    pos = line.indexOf(':',12);
                     if (pos < 0) {
                         errorCount++;
                         break;
@@ -1404,6 +1406,7 @@ void fishProtocol::finished() {
         isRunning = false;
     }
 }
+
 /** aborts command sequence and calls error() */
 void fishProtocol::error(int type, const QString &detail) {
     commandList.clear();
@@ -1412,8 +1415,9 @@ void fishProtocol::error(int type, const QString &detail) {
     SlaveBase::error(type,detail);
     isRunning = false;
 }
+
 /** executes a chain of commands */
-void fishProtocol::run() 
+void fishProtocol::run()
 /* This function writes to childFd fish commands (like #STOR 0 /tmp/test ...) that are stored in outBuf
 and reads from childFd the remote host's response. ChildFd is the fd to a process that communicates
 with .fishsrv.pl typically running on another computer. */
@@ -1449,25 +1453,20 @@ with .fishsrv.pl typically running on another computer. */
 	    // Do: send command and newlines, expect response then
 	    // Do not: send commands, expect response, send newlines, expect response on newlines
 	    // Newlines do not trigger a response.
-            while (FD_ISSET(childFd,&wfds) && outBufPos >= 0) 
-	    {
-#else
-            while (outBufPos >= 0) 
-	    {
-#endif
-#if 0
-                QString debug = QString::fromLatin1(outBuf+outBufPos,outBufLen-outBufPos);
-                myDebug( << "now writing " << (outBufLen-outBufPos) << " " << debug << endl);
-#endif
-#ifndef Q_WS_WIN
-                if (outBufLen-outBufPos > 0) rc = ::write(childFd,outBuf+outBufPos,outBufLen-outBufPos);
+            if (FD_ISSET(childFd,&wfds) && outBufPos >= 0) {
+                if (outBufLen-outBufPos > 0)
+                    rc = ::write(childFd, outBuf + outBufPos, outBufLen - outBufPos);
 #else
+            if (outBufPos >= 0) {
                 if (outBufLen-outBufPos > 0) {
                     rc = childPid->write(outBuf);
                 }
 #endif
-                else rc = 0;
-                if (rc >= 0) outBufPos += rc;
+                else
+                    rc = 0;
+
+                if (rc >= 0)
+                    outBufPos += rc;
                 else {
 #ifndef Q_WS_WIN
                     if (errno == EINTR)
@@ -1487,16 +1486,16 @@ with .fishsrv.pl typically running on another computer. */
                 }
             }
 #ifndef Q_WS_WIN
-            if (FD_ISSET(childFd,&rfds)) {
-                rc = ::read(childFd,buf+offset,32768-offset);
+            else if (FD_ISSET(childFd,&rfds)) {
+                rc = ::read(childFd, buf + offset, sizeof(buf) - offset);
 #else
-            if (childPid->waitForReadyRead(1000)) {
-                rc = childPid->read(buf+offset,32768-offset);
+            else if (childPid->waitForReadyRead(1000)) {
+                rc = childPid->read(buf + offset, sizeof(buf) - offset);
 #endif
                 //myDebug( << "read " << rc << " bytes" << endl);
                 if (rc > 0) {
-                    int noff = received(buf,rc+offset);
-                    if (noff > 0) memmove(buf,buf+offset+rc-noff,noff);
+                    int noff = received(buf, rc + offset);
+                    if (noff > 0) memmove(buf, buf + offset + rc - noff, noff);
                     //myDebug( << "left " << noff << " bytes: " << QString::fromLatin1(buf,offset) << endl);
                     offset = noff;
                 } else {
@@ -1517,6 +1516,7 @@ with .fishsrv.pl typically running on another computer. */
         }
     }
 }
+
 /** stat a file */
 void fishProtocol::stat(const KUrl& u){
     myDebug( << "@@@@@@@@@ stat " << u << endl);
