@@ -34,7 +34,6 @@
 
 #include <kconfig.h>
 #include <kconfiggroup.h>
-#include <QDir>
 #include <stdlib.h>
 
 // call for libsmbclient
@@ -135,6 +134,7 @@ bool SMBSlave::checkPassword(SMBUrl &url)
         share = share.mid(1);
     info.url.setPath('/' + share);
     info.verifyPath = true;
+    info.keepPassword = true;
 
     if ( share.isEmpty() )
         info.prompt = i18n(
@@ -161,7 +161,7 @@ bool SMBSlave::checkPassword(SMBUrl &url)
 }
 
 //--------------------------------------------------------------------------
-// Initalizes the smbclient library
+// Initializes the smbclient library
 //
 // Returns: 0 on success -1 with errno set on error
 bool SMBSlave::auth_initialize_smbc()
