@@ -46,7 +46,7 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
-#include <klibloader.h>
+#include <klibrary.h>
 #include <kdebug.h>
 #include <kservice.h>
 #include <kservicetype.h>
@@ -284,15 +284,12 @@ void ThumbnailProtocol::get(const KUrl &url)
 
     scaleDownImage(img, m_width, m_height);
 
-// ### FIXME
-#ifndef USE_KINSTANCE
     if (flags & ThumbCreator::DrawFrame) {
-        QPixmap pix = QPixmap::fromImage( img );
-        int x2 = pix.width() - 1;
-        int y2 = pix.height() - 1;
+        int x2 = img.width() - 1;
+        int y2 = img.height() - 1;
         // paint a black rectangle around the "page"
         QPainter p;
-        p.begin( &pix );
+        p.begin( &img );
         p.setPen( QColor( 48, 48, 48 ));
         p.drawLine( x2, 0, x2, y2 );
         p.drawLine( 0, y2, x2, y2 );
@@ -300,24 +297,7 @@ void ThumbnailProtocol::get(const KUrl &url)
         p.drawLine( 0, 0, x2, 0 );
         p.drawLine( 0, 0, 0, y2 );
         p.end();
-
-        const QBitmap& mask = pix.mask();
-        if (!mask.isNull()) { // need to update it so we can see the frame
-            QBitmap bitmap( mask );
-            QPainter painter;
-            painter.begin( &bitmap );
-            painter.drawLine( x2, 0, x2, y2 );
-            painter.drawLine( 0, y2, x2, y2 );
-            painter.drawLine( 0, 0, x2, 0 );
-            painter.drawLine( 0, 0, 0, y2 );
-            painter.end();
-
-            pix.setMask( bitmap );
-        }
-
-        img = pix.toImage();
     }
-#endif
 
     if ((flags & ThumbCreator::BlendIcon) && KIconLoader::global()->alphaBlending(KIconLoader::Desktop)) {
         // blending the mimetype icon in
@@ -447,7 +427,7 @@ void ThumbnailProtocol::drawPictureFrame(QPainter *painter, const QPoint &center
     float scaledFrameWidth = frameWidth / scaling;
 
     QTransform m;
-    m.rotate(qrand() % 16 - 8); // Random rotation ±8°
+    m.rotate(qrand() % 17 - 8); // Random rotation ±8°
     m.scale(scaling, scaling);
 
     QRectF frameRect(QPointF(0, 0), QPointF(image.width() + scaledFrameWidth*2, image.height() + scaledFrameWidth*2));
@@ -499,7 +479,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
         m_maxFileSize = globalConfig.readEntry("MaximumSize", 5 * 1024 * 1024); // 5 MByte default
     }
-    
+
     const int tiles = 2; //Count of items shown on each dimension
     const int spacing = 1;
     const int visibleCount = tiles * tiles;
@@ -507,7 +487,13 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
     // TODO: the margins are optimized for the Oxygen iconset
     // Provide a fallback solution for other iconsets (e. g. draw folder
     // only as small overlay, use no margins)
-    const QPixmap folder = KIconLoader::global()->loadMimeTypeIcon("inode-directory",
+
+    //Use the current (custom) folder icon
+    KUrl tempDirectory = directory;
+    tempDirectory.setScheme("file"); //iconNameForUrl will not work with the "thumbnail:/" scheme
+    QString iconName = KMimeType::iconNameForUrl(tempDirectory, S_IFDIR);
+
+    const QPixmap folder = KIconLoader::global()->loadMimeTypeIcon(iconName,
                                                                    KIconLoader::Desktop,
                                                                    qMin(m_width, m_height));
     const int folderWidth  = folder.width();
@@ -551,13 +537,13 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
     int skipped = 0;
 
     const int maxYPos = folderHeight - bottomMargin - segmentHeight;
-    
+
     while ((skipped <= skipValidItems) && (yPos <= maxYPos) && !hadThumbnail) {
         QDirIterator dir(localFile, QDir::Files | QDir::Readable);
         if (!dir.hasNext()) {
             break;
         }
-        
+
         while (dir.hasNext() && (yPos <= maxYPos)) {
             ++iterations;
             if (iterations > 500) {
@@ -581,16 +567,16 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
             if (!createSubThumbnail(subThumbnail, dir.filePath(), segmentWidth, segmentHeight)) {
                 continue;
             }
-            
+
             if (skipped < skipValidItems) {
                 ++skipped;
                 continue;
             }
-            
+
             // Seed the random number generator so that it always returns the same result
             // for the same directory and sequence-item
             qsrand(qHash(dir.filePath()));
-            
+
             if (hadFirstThumbnail.isEmpty()) {
                 hadFirstThumbnail = dir.filePath();
             }
@@ -616,7 +602,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
                 yPos += segmentHeight + spacing;
             }
         }
-        
+
         if (skipped != 0) { // Round up to full pages
             const int roundedDown = (skipped / visibleCount) * visibleCount;
             if (roundedDown < skipped) {
@@ -625,18 +611,18 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
                 skipped = roundedDown;
             }
         }
-        
+
         if (skipped == 0) {
             break; // No valid items were found
         }
-            
+
         // We don't need to iterate again and again: Subtract any multiple of "skipped" from the count we still need to skip
         skipValidItems -= (skipValidItems / skipped) * skipped;
         skipped = 0;
     }
-    
+
     p.end();
-    
+
     if (!hadThumbnail) {
         // Eventually propagate the contained items from a sub-directory
         QDirIterator dir(localFile, QDir::Dirs);
@@ -661,11 +647,11 @@ ThumbCreator* ThumbnailProtocol::getThumbCreator(const QString& plugin)
 {
     ThumbCreator *creator = m_creators[plugin];
     if (!creator) {
-        // Don't use KLibFactory here, this is not a QObject and
+        // Don't use KPluginFactory here, this is not a QObject and
         // neither is ThumbCreator
-        KLibrary *library = KLibLoader::self()->library(plugin);
-        if (library) {
-            newCreator create = (newCreator)library->resolveFunction("new_creator");
+        KLibrary library(plugin);
+        if (library.load()) {
+            newCreator create = (newCreator)library.resolveFunction("new_creator");
             if (create) {
                 creator = create();
             }
@@ -702,7 +688,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
         const KConfigGroup globalConfig(KGlobal::config(), "PreviewSettings");
         m_enabledPlugins = globalConfig.readEntry("Plugins", QStringList()
                                                              << "imagethumbnail"
-                                                             << "jpegthumbnail"
+                                                             << "jpegrotatedthumbnail"
                                                              << "videopreview");
     }
 
@@ -774,12 +760,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
 void ThumbnailProtocol::scaleDownImage(QImage& img, int maxWidth, int maxHeight)
 {
     if (img.width() > maxWidth || img.height() > maxHeight) {
-        const double imgRatio = (double)img.height() / (double)img.width();
-        if (imgRatio > (double)maxHeight / (double)maxWidth) {
-            img = img.scaled( int(qMax((double)maxHeight / imgRatio, 1.0)), maxHeight, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        } else {
-            img = img.scaled(maxWidth, int(qMax((double)maxWidth * imgRatio, 1.0)), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        }
+        img = img.scaled(maxWidth, maxHeight, Qt::KeepAspectRatio, Qt::SmoothTransformation);
     }
 }
 
