@@ -26,6 +26,7 @@
 #include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kservicetypetrader.h>
 
 #include <config-runtime.h>
 
@@ -47,7 +48,7 @@ KNotify::KNotify( QObject *parent )
 	loadConfig();
 	(void)new KNotifyAdaptor(this);
 	(void)new KSolidNotify(this);
-	QDBusConnection::sessionBus().registerObject("/Notify", this, QDBusConnection::ExportAdaptors 
+	QDBusConnection::sessionBus().registerObject("/Notify", this, QDBusConnection::ExportAdaptors
 	 /*|  QDBusConnection::ExportScriptableSlots |  QDBusConnection::ExportScriptableSignals*/ );
 }
 
@@ -57,7 +58,7 @@ KNotify::~KNotify()
 }
 
 
-void KNotify::loadConfig() 
+void KNotify::loadConfig()
 {
 	qDeleteAll(m_plugins);
 	m_plugins.clear();
@@ -66,10 +67,28 @@ void KNotify::loadConfig()
 	addPlugin(new NotifyByExecute(this));
 	addPlugin(new NotifyByLogfile(this));
         //TODO reactivate on Mac/Win when KWindowSystem::demandAttention will implemented on this system.
-#ifdef Q_WS_X11
+#ifndef Q_WS_MAC
 	addPlugin(new NotifyByTaskbar(this));
 #endif
 	addPlugin(new NotifyByKTTS(this));
+
+	KService::List offers = KServiceTypeTrader::self()->query("KNotify/NotifyMethod");
+
+	QVariantList args;
+	QString error;
+	
+	foreach (const KService::Ptr service, offers)
+	{
+		KNotifyPlugin *plugin = service->createInstance<KNotifyPlugin>(this, args, &error);
+		if (plugin)
+		{
+			addPlugin(plugin);
+		}
+		else
+		{
+			kDebug() << "Could not load plugin" << service->name() << "due to:" << error;
+		}
+	}
 }
 
 void KNotify::addPlugin( KNotifyPlugin * p )
@@ -93,12 +112,12 @@ void KNotify::closeNotification(int id)
 	if(!m_notifications.contains(id))
 		return;
 	Event *e=m_notifications[id];
-	
+
 	kDebug() << e->id << " ref=" << e->ref;
-	
+
 	//this has to be called before  plugin->close or we will get double deletion because of slotPluginFinished
 	m_notifications.remove(id);
-	
+
 	if(e->ref>0)
 	{
 		e->ref++;
@@ -125,10 +144,10 @@ int KNotify::event( const QString & event, const QString & appname, const Contex
 	e->config.image=image;
 	e->config.timeout=timeout;
 	e->config.winId=(WId)winId;
-	
+
 	m_notifications.insert(m_counter,e);
 	emitEvent(e);
-	
+
 	e->ref--;
 	kDebug() << e->id << " ref=" << e->ref;
 	if(e->ref==0)
@@ -146,12 +165,12 @@ void KNotify::update(int id, const QString &title, const QString &text, const KN
 		return;
 
 	Event *e=m_notifications[id];
-	
+
 	e->config.title=title;
 	e->config.text=text;
 	e->config.image = image;
 	e->config.actions = actions;
-	
+
 	foreach(KNotifyPlugin *p, m_plugins)
 	{
 		p->update(id, &e->config);
@@ -163,7 +182,7 @@ void KNotify::reemit(int id, const ContextList& contexts)
 		return;
 	Event *e=m_notifications[id];
 	e->config.contexts=contexts;
-	
+
 	emitEvent(e);
 }
 
@@ -172,6 +191,36 @@ void KNotify::emitEvent(Event *e)
 	QString presentstring=e->config.readEntry("Action");
 	QStringList presents=presentstring.split ('|');
 	
+	if (!e->config.contexts.isEmpty() && !presents.first().isEmpty()) 
+	{
+		//Check whether the present actions are absolute, relative or invalid
+		bool relative = presents.first().startsWith('+') || presents.first().startsWith('-');
+		bool valid = true;
+		foreach (const QString & presentAction, presents)
+			valid &=  ((presentAction.startsWith('+') || presentAction.startsWith('-')) == relative);
+		if (!valid) 
+		{
+			kDebug() << "Context " << e->config.contexts << "present actions are invalid! Fallback to default present actions";
+			Event defaultEvent = Event(e->config.appname, ContextList(), e->config.eventid);
+			QString defaultPresentstring=defaultEvent.config.readEntry("Action");
+			presents = defaultPresentstring.split ('|');
+		} else if (relative) 
+		{
+			// Obtain the list of present actions without context
+			Event noContextEvent = Event(e->config.appname, ContextList(), e->config.eventid);
+			QString noContextPresentstring = noContextEvent.config.readEntry("Action");
+			QSet<QString> noContextPresents = noContextPresentstring.split ('|').toSet();
+			foreach (const QString & presentAction, presents)
+			{
+				if (presentAction.startsWith('+'))
+					noContextPresents << presentAction.mid(1);
+				else
+					noContextPresents.remove(presentAction.mid(1));
+			}
+			presents = noContextPresents.toList();
+		}
+	}
+
 	foreach(const QString & action , presents)
 	{
 		if(!m_plugins.contains(action))
@@ -213,7 +262,7 @@ int KNotifyAdaptor::event(const QString &event, const QString &fromApp, const QV
 						const QString &title, const QString &text, const QByteArray& image,  const QStringList& actions,
 						int timeout, qlonglong winId)
 //						  const QDBusMessage & , int _return )
-								  
+
 {
 	/* I'm not sure this is the right way to read a a(ss) type,  but it seems to work */
 	ContextList contextlist;
@@ -234,7 +283,7 @@ int KNotifyAdaptor::event(const QString &event, const QString &fromApp, const QV
 		else
 			contextlist << qMakePair(context_key , s);
 	}
-	
+
 	return static_cast<KNotify *>(parent())->event(event, fromApp, contextlist, title, text, image, actions, timeout, WId(winId));
 }
 
