@@ -35,6 +35,8 @@
 #include <QtDBus/QtDBus>
 
 #include <kdebug.h>
+#include <klocalizedstring.h>
+#include <kpluginfactory.h>
 #include <kprotocolinfo.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
@@ -48,6 +50,7 @@
 #define ENV_VAR_PATTERN "\\$[a-zA-Z_][a-zA-Z0-9_]*"
 
 #define QL1S(x) QLatin1String(x)
+#define QL1C(x) QLatin1Char(x)
 
  /**
   * IMPORTANT:
@@ -84,7 +87,7 @@ static bool isValidShortURL( const QString& cmd )
   exp.setPattern( QL1S(FQDN_PATTERN) );
   if ( cmd.contains( exp ) )
   {
-    kDebug(7023) << cmd << " matches FQDN_PATTERN" << endl;
+    //kDebug(7023) << cmd << " matches FQDN_PATTERN" << endl;
 #if 0
     // something like wallpaper.png also matches a the FQDN pattern
     // but is very unlikely to be meant as such
@@ -99,7 +102,7 @@ static bool isValidShortURL( const QString& cmd )
   exp.setPattern( QL1S(IPv4_PATTERN) );
   if ( cmd.contains( exp ) )
   {
-    kDebug(7023) << cmd << " matches IPv4_PATTERN" << endl;
+    //kDebug(7023) << cmd << " matches IPv4_PATTERN" << endl;
     return true;
   }
 
@@ -107,11 +110,11 @@ static bool isValidShortURL( const QString& cmd )
   exp.setPattern( QL1S(IPv6_PATTERN) );
   if ( cmd.contains( exp ) )
   {
-    kDebug(7023) << cmd << " matches IPv6_PATTERN" << endl;
+    //kDebug(7023) << cmd << " matches IPv6_PATTERN" << endl;
     return true;
   }
 
-  kDebug(7023) << cmd << "' is not a short URL." << endl;
+  //kDebug(7023) << cmd << "' is not a short URL." << endl;
   return false;
 }
 
@@ -167,6 +170,8 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   const bool isMalformed = !url.isValid();
   QString protocol = url.protocol();
 
+  kDebug(7023) << cmd;
+
   // Fix misparsing of "foo:80", QUrl thinks "foo" is the protocol and "80" is the path.
   // However, be careful not to do that for valid hostless URLs, e.g. file:///foo!
   if (!protocol.isEmpty() && url.host().isEmpty() && !url.path().isEmpty()
@@ -341,7 +346,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   const QString abs_path = data.absolutePath();
 
   const bool canBeAbsolute = (protocol.isEmpty() && !abs_path.isEmpty());
-  const bool canBeLocalAbsolute = (canBeAbsolute && abs_path[0] =='/');
+  const bool canBeLocalAbsolute = (canBeAbsolute && abs_path[0] =='/' && !isMalformed);
   bool exists = false;
 
   /*kDebug(7023) << "abs_path=" << abs_path
@@ -370,8 +375,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     }
   }
 
-  if( isLocalFullPath && !exists )
-  {
+  if (isLocalFullPath && !exists && !isMalformed) {
     exists = ( stat( QFile::encodeName(path).data() , &buff ) == 0 );
 
     if ( !exists ) {
@@ -476,17 +480,23 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   // TODO: Make configurable at some point...
   if ( !cmd.contains( ' ' ) )
   {
-    QList<URLHint>::ConstIterator it;
-    for( it = m_urlHints.begin(); it != m_urlHints.end(); ++it )
+    QList<URLHint>::ConstIterator it = m_urlHints.begin();
+    QList<URLHint>::ConstIterator itEnd = m_urlHints.end();
+    for( ; it != itEnd; ++it )
     {
       QRegExp match( (*it).regexp );
       if ( match.indexIn( cmd ) == 0 )
       {
         //kDebug(7023) << "match - prepending" << (*it).prepend;
-        cmd.prepend( (*it).prepend );
-        setFilteredUri( data, KUrl( cmd ) );
-        setUriType( data, (*it).type );
-        return true;
+        QString cmdStr = (*it).prepend;
+        cmdStr += cmd;
+        KUrl url ( cmdStr );
+        if (KProtocolInfo::isKnownProtocol(url))
+        {
+          setFilteredUri( data, url );
+          setUriType( data, (*it).type );
+          return true;
+        }
       }
     }
 
@@ -494,13 +504,23 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // candidate and append the default protocol the user supplied. (DA)
     if ( protocol.isEmpty() && isValidShortURL(cmd) )
     {
-      kDebug(7023) << "Valid short url, from malformed url -> using default proto="
-               << m_strDefaultProtocol << endl;
+      QString urlStr = data.defaultUrlScheme();
+      if (urlStr.isEmpty())
+          urlStr = m_strDefaultUrlScheme;
 
-      cmd.insert( 0, m_strDefaultProtocol );
-      setFilteredUri( data, KUrl( cmd ));
-      setUriType( data, KUriFilterData::NetProtocol );
-      return true;
+      const int index = urlStr.indexOf(QL1C(':'));
+      if (index == -1)
+        urlStr += QL1S("://");
+
+      urlStr += cmd;
+
+      KUrl url (urlStr);
+      if (KProtocolInfo::isKnownProtocol(url))
+      {
+        setFilteredUri(data, url);
+        setUriType(data, KUriFilterData::NetProtocol);
+        return true;
+      }
     }
   }
 
@@ -512,7 +532,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     u.setPath(path);
     u.setRef(ref);
 
-    if (!KAuthorized::authorizeUrlAction( QLatin1String("open"), KUrl(), u))
+    if (!KAuthorized::authorizeUrlAction( QL1S("open"), KUrl(), u))
     {
       // No authorization, we pretend it exists and will get
       // an access denied error later on.
@@ -547,7 +567,7 @@ void KShortUriFilter::configure()
   KConfig config( objectName() + QL1S( "rc"), KConfig::NoGlobals );
   KConfigGroup cg( config.group("") );
 
-  m_strDefaultProtocol = cg.readEntry( "DefaultProtocol", QString("http://") );
+  m_strDefaultUrlScheme = cg.readEntry( "DefaultProtocol", QString("http://") );
   const EntryMap patterns = config.entryMap( QL1S("Pattern") );
   const EntryMap protocols = config.entryMap( QL1S("Protocol") );
   KConfigGroup typeGroup(&config, "Type");
