@@ -23,11 +23,17 @@
 #include "ui_nepomukconfigwidget.h"
 #include "nepomukserverinterface.h"
 #include "strigiserviceinterface.h"
-#include "nepomukservicemanagerinterface.h"
 
-class FolderSelectionModel;
+#include <Nepomuk/Query/Query>
+
+class QRadioButton;
+class QAbstractButton;
 
 namespace Nepomuk {
+
+    class IndexFolderSelectionDialog;
+    class StatusWidget;
+
     class ServerConfigModule : public KCModule, private Ui::NepomukConfigWidget
     {
         Q_OBJECT
@@ -42,17 +48,32 @@ namespace Nepomuk {
         void defaults();
 
     private Q_SLOTS:
-        void slotUpdateStrigiStatus();
-        void recreateStrigiInterface();
+        void updateNepomukServerStatus();
+        void updateStrigiStatus();
+        void updateBackupStatus();
+        void recreateInterfaces();
+        void slotCustomQueryButtonClicked();
+        void slotEditIndexFolders();
+        void slotCustomQueryToggled( bool );
+        void slotStatusDetailsClicked();
+        void slotBackupFrequencyChanged();
+        void slotManualBackup();
+        void slotRestoreBackup();
 
     private:
-        org::kde::NepomukServer m_serverInterface;
-        org::kde::nepomuk::ServiceManager m_serviceManagerInterface;
+        QRadioButton* buttonForQuery( const Query::Query& query ) const;
+        Nepomuk::Query::Query queryForButton( QAbstractButton* button ) const;
+
+        bool m_nepomukAvailable;
+
+        org::kde::NepomukServer* m_serverInterface;
         org::kde::nepomuk::Strigi* m_strigiInterface;
 
-        FolderSelectionModel* m_folderModel;
+        IndexFolderSelectionDialog* m_indexFolderSelectionDialog;
 
         bool m_failedToInitialize;
+
+        QString m_customQuery;
     };
 }
 
