@@ -19,10 +19,6 @@
 */
 
 #include "kio_nepomuk.h"
-#include "nie.h"
-#include "nfo.h"
-//#include "nmm.h"
-#include "pimo.h"
 #include "resourcepagegenerator.h"
 #include "nepomuksearchurltools.h"
 #include "resourcestat.h"
@@ -49,6 +45,9 @@
 #include <Nepomuk/Query/Query>
 #include <Nepomuk/Query/ComparisonTerm>
 #include <Nepomuk/Query/ResourceTerm>
+#include <Nepomuk/Vocabulary/NFO>
+#include <Nepomuk/Vocabulary/NIE>
+#include <Nepomuk/Vocabulary/PIMO>
 
 #include <Soprano/Vocabulary/RDF>
 #include <Soprano/Vocabulary/NAO>
@@ -61,6 +60,12 @@
 #include <Solid/StorageAccess>
 
 
+namespace {
+    bool noFollowSet( const KUrl& url ) {
+        return( url.encodedQueryItemValue( "noFollow" ) == "true" );
+    }
+}
+
 Nepomuk::NepomukProtocol::NepomukProtocol( const QByteArray& poolSocket, const QByteArray& appSocket )
     : KIO::ForwardingSlaveBase( "nepomuk", poolSocket, appSocket )
 {
@@ -104,14 +109,15 @@ void Nepomuk::NepomukProtocol::get( const KUrl& url )
     kDebug() << url;
 
     m_currentOperation = Get;
+    const bool noFollow = noFollowSet( url );
 
     Nepomuk::Resource res = splitNepomukUrl( url );
-    if ( Nepomuk::isRemovableMediaFile( res ) ) {
+    if ( !noFollow && Nepomuk::isRemovableMediaFile( res ) ) {
         error( KIO::ERR_SLAVE_DEFINED,
                i18nc( "@info", "Please insert the removable medium <resource>%1</resource> to access this file.",
                       getFileSystemLabelForRemovableMediaFileUrl( res ) ) );
     }
-    else if ( !Nepomuk::nepomukToFileUrl( url ).isEmpty() ) {
+    else if ( !noFollow && !Nepomuk::nepomukToFileUrl( url ).isEmpty() ) {
         ForwardingSlaveBase::get( url );
     }
     else {
@@ -137,6 +143,7 @@ void Nepomuk::NepomukProtocol::get( const KUrl& url )
         }
         else {
             ResourcePageGenerator gen( res );
+            gen.setFlagsFromUrl( url );
             data( gen.generatePage() );
         }
         finished();
@@ -164,7 +171,8 @@ void Nepomuk::NepomukProtocol::stat( const KUrl& url )
     kDebug() << url;
 
     m_currentOperation = Stat;
-    if ( !Nepomuk::nepomukToFileUrl( url ).isEmpty() ) {
+    const bool noFollow = noFollowSet( url );
+    if ( !noFollow && !Nepomuk::nepomukToFileUrl( url ).isEmpty() ) {
         ForwardingSlaveBase::stat( url );
     }
     else {
@@ -175,7 +183,7 @@ void Nepomuk::NepomukProtocol::stat( const KUrl& url )
             error( KIO::ERR_DOES_NOT_EXIST, strippedUrl.prettyUrl() );
         }
         else {
-            KIO::UDSEntry uds = Nepomuk::statNepomukResource( res );
+            KIO::UDSEntry uds = Nepomuk::statNepomukResource( res, noFollow );
             statEntry( uds );
             finished();
         }
@@ -191,6 +199,11 @@ void Nepomuk::NepomukProtocol::mimetype( const KUrl& url )
     kDebug() << url;
 
     m_currentOperation = Other;
+    if ( noFollowSet( url ) ) {
+        mimeType( "text/html" );
+        finished();
+        return;
+    }
 
     QString filename;
     Nepomuk::Resource res = Nepomuk::splitNepomukUrl( url, &filename );
@@ -250,7 +263,7 @@ void Nepomuk::NepomukProtocol::del(const KUrl& url, bool isFile)
 
 bool Nepomuk::NepomukProtocol::rewriteUrl( const KUrl& url, KUrl& newURL )
 {
-    if ( url.queryItemValue( QLatin1String( "noFollow" ) ) == QLatin1String( "true" ) )
+    if ( noFollowSet( url ) )
         return false;
 
     newURL = Nepomuk::nepomukToFileUrl( url, m_currentOperation == Get );
