@@ -23,6 +23,7 @@
 
 #include <QtCore/QUrl>
 #include <QtCore/QVariant>
+#include <QtCore/QSet>
 
 namespace Soprano {
     class Model;
@@ -32,8 +33,8 @@ namespace Soprano {
 }
 
 class KInotify;
-
 class KUrl;
+class RegExpCache;
 
 namespace Nepomuk {
 
@@ -59,7 +60,7 @@ namespace Nepomuk {
 
     private Q_SLOTS:
         void slotFileMoved( const QString& from, const QString& to );
-        void slotFileDeleted( const QString& path, bool isDir );
+        void slotFileDeleted( const QString& urlString, bool isDir );
         void slotFilesDeleted( const QStringList& path );
         void slotFileCreated( const QString& );
         void slotFileModified( const QString& );
@@ -68,13 +69,28 @@ namespace Nepomuk {
 #ifdef BUILD_KINOTIFY
         void slotInotifyWatchUserLimitReached();
 #endif
+        /**
+         * To be called whenever the list of indexed folders changes. This is done because
+         * the indexed folders are watched with the 'KInotify::EventCreate' event, and the
+         * non-indexed folders are not.
+         */
+        void updateIndexedFoldersWatches();
 
     private:
+        /**
+         * Returns true if the path is one that should be always ignored.
+         * This includes such things like temporary files and folders as
+         * they are created for example by build systems.
+         */
+        bool ignorePath( const QString& path );
+
         MetadataMover* m_metadataMover;
 
 #ifdef BUILD_KINOTIFY
         KInotify* m_dirWatch;
 #endif
+
+        RegExpCache* m_pathExcludeRegExpCache;
     };
 }
 
