@@ -25,15 +25,14 @@
 #include <QtCore/QStringList>
 
 namespace Nepomuk {
-    
     class Core : public Soprano::Server::ServerCore
     {
         Q_OBJECT
-	
+
     public:
         Core( QObject* parent = 0 );
         ~Core();
-	
+
         /**
          * reimplemented from ServerCore
          */
@@ -51,30 +50,20 @@ namespace Nepomuk {
          */
         bool initialized() const;
 
-    public Q_SLOTS:
-        void optimize( const QString& repoName );
-
     Q_SIGNALS:
         void initializationDone( bool success );
 
     private Q_SLOTS:
         void slotRepositoryOpened( Repository* repo, bool success );
+        void slotOntologiesLoaded();
 
     private:
-        /**
-         * reimplemented from ServerCode
-         */
-        Soprano::Model* createModel( const QList<Soprano::BackendSetting>& settings );
-        void createRepository( const QString& name );
+        Soprano::Model* createModel( const Soprano::BackendSettings& );
 
-        RepositoryMap m_repositories;
+        /// the one single "main" repository Nepomuk uses
+        Repository* m_repository;
 
-        // initialization
-        QStringList m_openingRepositories;
-        QString m_currentRepoName;
-
-        // true if one of the repos could not be opened
-        bool m_failedToOpenRepository;
+        bool m_initialized;
     };
 }
 
