@@ -25,8 +25,7 @@
 
 #include <Plasma/Applet>
 
-#include "../backportglobal.h"
-#include "appletinterface.h"
+#include "backportglobal.h"
 
 #define DECLARE_INT_NUMBER_GET_METHOD(Class, __get__) \
 BEGIN_DECLARE_METHOD(Class, __get__) { \
@@ -119,10 +118,15 @@ BEGIN_DECLARE_METHOD(QGraphicsGridLayout, addItem) {
     return eng->undefinedValue();
 } END_DECLARE_METHOD
 
-BEGIN_DECLARE_METHOD(QGraphicsItem, toString) {
+BEGIN_DECLARE_METHOD(QGraphicsGridLayout, toString) {
     return QScriptValue(eng, "QGraphicsGridLayout");
 } END_DECLARE_METHOD
 
+BEGIN_DECLARE_METHOD(QGraphicsGridLayout, activate) {
+    self->activate();
+    return eng->undefinedValue();
+} END_DECLARE_METHOD
+
 /////////////////////////////////////////////////////////////
 
 class PrototypeGridLayout : public QGraphicsGridLayout
@@ -169,6 +173,7 @@ QScriptValue constructGridLayoutClass(QScriptEngine *eng)
     ADD_METHOD(proto, setContentsMargins);
     ADD_METHOD(proto, addItem);
     ADD_METHOD(proto, toString);
+    ADD_METHOD(proto, activate);
 
     QScript::registerPointerMetaType<QGraphicsGridLayout>(eng, proto);
 
